# MaLTHA

- MaLTHA works as a static site generator that use Markdown format with TOML/HTML hybrid annotation.
- MaLTHA stands for "**Ma**rkdown **L**anguage with **T**OML/**H**TML **H**ybrid **A**nnotation"

- Homepage: <https://github.com/SotongDJ/MaLTHA>

## Work

- Brief example
  - [SotongDJ/redirect](https://github.com/SotongDJ/redirect)
  - under "link" and "*_files" folders: example of TOML/HTML hybrid annotated Markdown files
- Requirement
  - config.toml
  - git ignore (optional)
  - github actions (optional)

## Disclaimer

- MaLTHA still work in progess

## Changelog

- v0.3.1
  - modified for the modulization
- v0.3.0 # still W.I.P.
  - release on PyPI
- v0.2.10
  - add "tables" into markdown2 extras
- v0.2.9
  - use rtoml instead of tomlkit
- v0.2.8
  - add "git submodule set-branch" to README and pyMoTH.yml
- v0.2.7
  - use fenced-code-blocks (markdown2)
- v0.2.6
  - adjust code for PEP (pylint)
- v0.2.5
  - fix canonical_url in categories and pagination
- v0.2.4
  - extend support of opengraph meta tag and add validator for trth.nl
- v0.2.3
  - change default setting (pyMoTH.yml)
